/***************************************************************************
 * This file is part of the project AqFoxExt.                              *
 * AqFoxExt (c) by 2011 Martin Preuss, all rights reserved.                *
 *                                                                         *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef FXXCOMBOEDIT_HPP
#define FXXCOMBOEDIT_HPP

#include <fx.h>

#include <aqfoxext/aqfoxext.h>

#include <gwen-gui-fox16/theme.h>

#include <list>


using namespace FX;

/**
 * If the ESC is pressed while the pane is open then the pane is closed. If ESC is
 * pressed while the pane is not open the signal SEL_DESELECTED is sent (due to lack
 * of a more matching signal, some think like SEL_CANCEL would be nice).
 */
class AQFOXEXT_API FXXComboEdit : public THEMECOMBOBOX {
  FXDECLARE(FXXComboEdit)

protected:
  FXXComboEdit(){}
private:
  std::list<FXString> _entries;
  int m_neededWidth;

  void _populateList(FXbool adjustPaneState);

public:
  long onTextChanged(FXObject*,FXSelector,void*);
  long onTextCommand(FXObject*, FXSelector, void*);
  long onTextKeyPress(FXObject*, FXSelector, void*);
  long onFocusUp(FXObject*,FXSelector,void*);
  long onFocusDown(FXObject*,FXSelector,void*);
  long onMouseWheel(FXObject*,FXSelector,void* ptr);
  long onFocusIn(FXObject*,FXSelector,void*);
  long onFocusSelf(FXObject*,FXSelector,void*);

  /// Construct a Combo Box widget with room to display cols columns of text
  FXXComboEdit(FXComposite *p, FXint cols,
               FXObject* tgt=NULL,
               FXSelector sel=0,
               FXuint opts=COMBOBOX_NORMAL,
               FXint x=0,FXint y=0,FXint w=0,FXint h=0,
               FXint pl=DEFAULT_PAD,
               FXint pr=DEFAULT_PAD,
               FXint pt=DEFAULT_PAD,
               FXint pb=DEFAULT_PAD);
  ~FXXComboEdit();

  void setText(const FXString& text);
  void addEntry(const char *s);

  void reloadList();

  FXString getText();

  void selectAll();

  void layout();

};


#endif


