/***************************************************************************
 * This file is part of the project AqFoxExt.                              *
 * AqFoxExt (c) by 2011 Martin Preuss, all rights reserved.                *
 *                                                                         *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FXXMENUCONTAINER_HPP
#define FXXMENUCONTAINER_HPP


#include <fx.h>

#include <aqfoxext/aqfoxext.h>


class FXXAction;



class AQFOXEXT_API FXXMenuContainer: public FXObject {
  FXDECLARE(FXXMenuContainer)
  friend class FXXAction;
public:
  enum {
    TYPE_UNKNOWN=-1,
    TYPE_MENUBAR=0,
    TYPE_COMMAND,
    TYPE_TITLE,
    TYPE_CASCADE
  };
protected:
  FXint typ;
  FXString name;
  FXObjectListOf<FXXMenuContainer> children;

  FXXAction *action;
  FXXMenuContainer *parent;
  FXComposite *window;
  FXMenuBar *menuBar;
  FXMenuTitle *menuTitle;
  FXMenuCommand *menuCommand;
  FXMenuCascade *menuCascade;

  FXXMenuContainer();
  FXXMenuContainer(FXXMenuContainer *parent,
                   FXint typ,
                   const FXString &name,
                   const FXString &text,
                   FXIcon *ic=NULL,
                   FXObject *tgt=NULL,
                   FXSelector sel=0,
                   FXuint opts=0);

  FXXMenuContainer(FXComposite *w, FXuint opts=0);

  void addChild(FXXMenuContainer *ch);
  void removeChild(FXXMenuContainer *ch);

public:
  ~FXXMenuContainer();

  const FXString &getName() const { return name;};

  FXXMenuContainer *getChildByName(const FXString &n);

  const FXObjectListOf<FXXMenuContainer> &getChildren() const {
    return children;};

  void insertSpacer(FXuint opts);

  static AQFOXEXT_API FXXMenuContainer *createMenuBar(FXComposite *w, FXuint opts=0);
  static AQFOXEXT_API FXXMenuContainer *createMenuCommand(FXXMenuContainer *parent,
                                                          const FXString &name,
                                                          const FXString &text,
                                                          FXIcon *ic=NULL,
                                                          FXObject *tgt=NULL,
                                                          FXSelector sel=0,
                                                          FXuint opts=0);
  static AQFOXEXT_API FXXMenuContainer *createMenuCommand(FXXMenuContainer *parent,
                                                          FXXAction *act,
                                                          FXbool withText=TRUE,
                                                          FXbool withIcon=FALSE,
                                                          FXuint opts=0);
  static AQFOXEXT_API FXXMenuContainer *createMenuTitle(FXXMenuContainer *parent,
                                                        const FXString &name,
                                                        const FXString &text,
                                                        FXIcon *ic=NULL,
                                                        FXuint opts=0);

  static AQFOXEXT_API FXXMenuContainer *createMenuCascade(FXXMenuContainer *parent,
                                                          const FXString &name,
                                                          const FXString &text,
                                                          FXIcon *ic=NULL,
                                                          FXuint opts=0);

  void enable();
  void disable();
  void create();

  FXPopup *getMenuPane();

};



#endif


