/*
FoxTray, system tray icon for the FOX Toolkit

Copyright (c) 2008, Hendrik Rittich
All rights reserved.

Redistribution and use in source and binary forms, with or without 
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in 
      the documentation and/or other materials provided with the 
      distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef FX_TRAY_ICON_H
#define FX_TRAY_ICON_H

#include "fx.h"

#include <aqfoxext/aqfoxext.h>

#include <windows.h>
#include <shellapi.h>

/*
 INSTALLING:

 Add the following line to the FXIcon class in fxicon.h
   friend class FXXTrayIcon
*/

namespace FX {

enum {
    TRAY_MENU_ON_LEFT = 0x0001,
    TRAY_MENU_ON_RIGHT = 0x0002,
    TRAY_CMD_ON_LEFT = 0x0004,
    TRAY_CMD_ON_RIGHT = 0x0008
};

class AQFOXEXT_API FXXTrayIcon : public FXTopWindow
{
    FXDECLARE(FXXTrayIcon)
public:
	FXXTrayIcon(FXApp* app, const FXString& text, FXIcon* icon, 
        FXPopup* pup = NULL, FXObject* target = 0, FXSelector sel = 0,
        FXuint opts = TRAY_MENU_ON_LEFT);
	~FXXTrayIcon();

	void create();

    void mapToManager();

	long onEvent(FXObject*, FXSelector, void* ptr);

    void setMenu(FXPopup* pup) { mPup = pup; }
    FXPopup* getMenu() const { return mPup; }

    void setIcon(FXIcon* icon);
    inline FXIcon* getIcon() const { return mIcon; } 

    void setText(const FXString& text);
    inline const FXString& getText() const { return mTooltip; }

    static AQFOXEXT_API HICON createMswIcon(FXIcon* icon);
private:
	HICON mWIcon;
	FXIcon* mIcon;
	DWORD mTrayID;

	FXPopup* mPup;
	FXuint mOpts;
	FXString mTooltip;

	static DWORD sTrayIconCount;

	FXXTrayIcon()
	{}

    void setupNotifyData(NOTIFYICONDATA* data);
};

}


#endif
